@@ -41,7 +41,7 @@ if typing.TYPE_CHECKING:  # pragma: no cover
 PathLike = Union[str, os.PathLike]
 
 
-__version__ = '0.1.0'
+__version__ = '0.1.2'
 
 
 class _depstr:
@@ -596,7 +596,7 @@ class Project():
         with _edit_targz(meson_dist, sdist) as content:
             # rename from meson name to sdist name if necessary
             if dist_name != meson_dist_name:
-                shutil.move(content / meson_dist_name, content / dist_name)
+                shutil.move(str(content / meson_dist_name), str(content / dist_name))
 
             # add PKG-INFO to dist file to make it a sdist
             content.joinpath(dist_name, 'PKG-INFO').write_bytes(self.metadata)
