@@ -13,14 +13,10 @@ def test_contents(package_library, wheel_library):
     artifact = wheel.wheelfile.WheelFile(wheel_library)
 
     for name, regex in zip(sorted(artifact.namelist()), [
-        re.escape('library-1.0.0.data/'),
-        re.escape('library-1.0.0.data/scripts'),
         re.escape('library-1.0.0.data/scripts/example'),
-        re.escape('library-1.0.0.dist-info/'),
         re.escape('library-1.0.0.dist-info/METADATA'),
         re.escape('library-1.0.0.dist-info/RECORD'),
         re.escape('library-1.0.0.dist-info/WHEEL'),
-        re.escape('library.libs/'),
         r'library\.libs/libexample.*\.so',
     ]):
         assert re.match(regex, name), f'`{name}` does not match `{regex}`'
@@ -31,14 +27,10 @@ def test_purelib_and_platlib(wheel_purelib_and_platlib):
 
     assert set(artifact.namelist()) == {
         f'plat{EXT_SUFFIX}',
-        'purelib_and_platlib-1.0.0.data/',
-        'purelib_and_platlib-1.0.0.data/purelib/',
         'purelib_and_platlib-1.0.0.data/purelib/pure.py',
-        'purelib_and_platlib-1.0.0.dist-info/',
         'purelib_and_platlib-1.0.0.dist-info/METADATA',
         'purelib_and_platlib-1.0.0.dist-info/RECORD',
         'purelib_and_platlib-1.0.0.dist-info/WHEEL',
-        'purelib_and_platlib.libs/',
     }
 
 
